==> request-tracker4_4.4.4+dfsg.orig-third-party-source.tar.gz: rt-4.4.4/devel/third-party/ckeditor-src/plugins/link/lang/da.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'da', {
	acccessKey: 'Genvejstast',
	advanced: 'Avanceret',
	advisoryContentType: 'Indholdstype',
	advisoryTitle: 'Titel',
	anchor: {
		toolbar: 'Indsæt/redigér bogmærke',
		menu: 'Egenskaber for bogmærke',
		title: 'Egenskaber for bogmærke',
		name: 'Bogmærkenavn',
		errorName: 'Indtast bogmærkenavn',
		remove: 'Fjern bogmærke'
	},
	anchorId: 'Efter element-Id',
	anchorName: 'Efter ankernavn',
	charset: 'Tegnsæt',
	cssClasses: 'Typografiark',
	emailAddress: 'E-mailadresse',
	emailBody: 'Besked',
	emailSubject: 'Emne',
	id: 'Id',
	info: 'Generelt',
	langCode: 'Tekstretning',
	langDir: 'Tekstretning',
	langDirLTR: 'Fra venstre mod højre (LTR)',
	langDirRTL: 'Fra højre mod venstre (RTL)',
	menu: 'Redigér hyperlink',
	name: 'Navn',
	noAnchors: '(Ingen bogmærker i dokumentet)',
	noEmail: 'Indtast e-mailadresse!',
	noUrl: 'Indtast hyperlink-URL!',
	other: '<anden>',
	popupDependent: 'Koblet/dependent (Netscape)',
	popupFeatures: 'Egenskaber for popup',
	popupFullScreen: 'Fuld skærm (IE)',
	popupLeft: 'Position fra venstre',
	popupLocationBar: 'Adresselinje',
	popupMenuBar: 'Menulinje',
	popupResizable: 'Justérbar',
	popupScrollBars: 'Scrollbar',
	popupStatusBar: 'Statuslinje',
	popupToolbar: 'Værktøjslinje',
	popupTop: 'Position fra toppen',
	rel: 'Relation',
	selectAnchor: 'Vælg et anker',
	styles: 'Typografi',
	tabIndex: 'Tabulatorindeks',
	target: 'Mål',
	targetFrame: '<ramme>',
	targetFrameName: 'Destinationsvinduets navn',
	targetPopup: '<popup vindue>',
	targetPopupName: 'Popupvinduets navn',
	title: 'Egenskaber for hyperlink',
	toAnchor: 'Bogmærke på denne side',
	toEmail: 'E-mail',
	toUrl: 'URL',
	toolbar: 'Indsæt/redigér hyperlink',
	type: 'Type',
	unlink: 'Fjern hyperlink',
	upload: 'Upload'
} );

==> request-tracker5_5.0.3+dfsg.orig-third-party-source.tar.gz: rt-5.0.3/devel/third-party/ckeditor-src/plugins/link/lang/da.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'da', {
	acccessKey: 'Genvejstast',
	advanced: 'Avanceret',
	advisoryContentType: 'Indholdstype',
	advisoryTitle: 'Titel',
	anchor: {
		toolbar: 'Indsæt/redigér bogmærke',
		menu: 'Egenskaber for bogmærke',
		title: 'Egenskaber for bogmærke',
		name: 'Bogmærkenavn',
		errorName: 'Indtast bogmærkenavn',
		remove: 'Fjern bogmærke'
	},
	anchorId: 'Efter element-Id',
	anchorName: 'Efter ankernavn',
	charset: 'Tegnsæt',
	cssClasses: 'Typografiark',
	download: 'Tving Download',
	displayText: 'Vis tekst',
	emailAddress: 'E-mailadresse',
	emailBody: 'Besked',
	emailSubject: 'Emne',
	id: 'Id',
	info: 'Generelt',
	langCode: 'Tekstretning',
	langDir: 'Tekstretning',
	langDirLTR: 'Fra venstre mod højre (LTR)',
	langDirRTL: 'Fra højre mod venstre (RTL)',
	menu: 'Redigér hyperlink',
	name: 'Navn',
	noAnchors: '(Ingen bogmærker i dokumentet)',
	noEmail: 'Indtast e-mailadresse!',
	noUrl: 'Indtast hyperlink-URL!',
	noTel: 'Please type the phone number', // MISSING
	other: '<anden>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Koblet/dependent (Netscape)',
	popupFeatures: 'Egenskaber for popup',
	popupFullScreen: 'Fuld skærm (IE)',
	popupLeft: 'Position fra venstre',
	popupLocationBar: 'Adresselinje',
	popupMenuBar: 'Menulinje',
	popupResizable: 'Justérbar',
	popupScrollBars: 'Scrollbar',
	popupStatusBar: 'Statuslinje',
	popupToolbar: 'Værktøjslinje',
	popupTop: 'Position fra toppen',
	rel: 'Relation',
	selectAnchor: 'Vælg et anker',
	styles: 'Typografi',
	tabIndex: 'Tabulatorindeks',
	target: 'Mål',
	targetFrame: '<ramme>',
	targetFrameName: 'Destinationsvinduets navn',
	targetPopup: '<popup vindue>',
	targetPopupName: 'Popupvinduets navn',
	title: 'Egenskaber for hyperlink',
	toAnchor: 'Bogmærke på denne side',
	toEmail: 'E-mail',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Indsæt/redigér hyperlink',
	type: 'Type',
	unlink: 'Fjern hyperlink',
	upload: 'Upload'
} );
